Learn R Programming

dyebias (version 1.32.0)

dyebias-package: The GASSCO method for correcting for slide-dependent gene-specific dye bias

Description

Many two-colour hybridizations suffer from a dye bias that is both gene-specific and slide-specific. The former depends on the content of the nucleotide used for labeling; the latter depends on the labeling percentage. The slide-dependency was hitherto not recognized, and made addressing the artefact impossible. Given a reasonable number of dye-swapped pairs of hybridizations, or of same vs. same hybridizations, both the gene- and slide-biases can be estimated and corrected using the GASSCO method (Margaritis et al., Mol. Sys. Biol. 5:266 (2009), doi:10.1038/msb.2009.21)

Arguments

Details

Package:
dyebias
Type:
Package
Version:
1.7.1
Date:
26 May 2010
Licence:
GPL-3

See Also

dyebias.application.subset, dyebias.apply.correction, dyebias.boxplot, dyebias.estimate.iGSDBs, dyebias.monotonicity, dyebias.monotonicityplot, dyebias.rgplot, dyebias.trendplot.