Learn R Programming

dyebias (version 1.32.0)

dyebias.application.subset: Return a subset of reporters that can be dye bias-corrected reasonably well

Description

Convenience function returning a subset of reporters that can be expected to be corrected reasonably well. Often, the logical AND of this set and that of maW(data.norm) == 1.0 is used. The resulting subset is passed as the application.subset-argument to dyebias.apply.correction.

Usage

dyebias.application.subset(data.raw=NULL, min.SNR=1.5, use.background=FALSE, maxA=15)

Arguments

data.raw
A marrayRaw object whose normalized data is to be dye bias-corrected.
min.SNR
The minimum signal to noise ratio to require. It is loosely defined here as the foreground over the background signal. The background signal may not be real; see below.
use.background
Logical indicating whether or not to use the background signals maRb(data.raw) and maGb(data.raw). If the data.raw object does not have them, specify use.background=FALSE. This will use the smallest foreground of all reporters instead of the real backgrounds.
maxA
The maximum signal that is still allowed.

Value

A matrix of logicals with the same dimensions as those of maRf{data.raw} is returned.

Details

This routine requires an marrayRaw object since only that contains the background intensities. If you only have normalized data, use something like

    bg <- matrix(0.5, nrow=maNspots(data.norm), ncol=maNsamples(data.norm))
    data.raw <- new("marrayRaw", maRf=maR(data.norm), maGf=maG(data.norm),
                                 maRb=bg, maGb=bg, maW=maW(data.norm))
  

References

Margaritis, T., Lijnzaad, P., van Leenen, D., Bouwmeester, D., Kemmeren, P., van Hooff, S.R and Holstege, F.C.P. (2009) Adaptable gene-specific dye bias correction for two-channel DNA microarrays. Molecular Systems Biology, 5:266, 2009. doi: 10.1038/msb.2009.21.

See Also

dyebias.apply.correction

Examples

Run this code
  ## First load data and estimate the iGSDBs
  ## (see dyebias.estimate.iGSDBs)

                                      

  ### choose the estimators and which spots to correct:
  estimator.subset <- dyebias.umcu.proper.estimators(maInfo(maGnames(data.norm)))

  ### choose which genes to dye bias correct. Typically, this is based
  ### both on flagged spots and intensity
  application.subset <- maW(data.norm) == 1 &
          dyebias.application.subset(data.raw=data.raw, use.background=TRUE)

  summary(application.subset)

Run the code above in your browser using DataLab